simplepy library

Classes

Interpreter
Executes the Abstract Syntax Tree (AST) representing the script.
Lexer
A lexer (also known as scanner or tokenizer) that breaks down Python subset source code into a sequence of Token objects.
NativeFunction
Wraps a native Dart function, making it callable from the interpreted language.
Parser
Parses a stream of Tokens (produced by a Lexer) into an Abstract Syntax Tree (AST) consisting of Stmt and Expr nodes.
PyFunction
Represents a user-defined function declared using the def keyword or the expression body of al lambdafunction.
PyInstance
Represents an instance of a PyClass at runtime.
PyList
Wrapper for python list
PyNum
Python-like number: can be either integer (BigInt) or float (double).
PyTuple
Wrapper for python tuple
Stmt
Base class for all statement nodes in the Abstract Syntax Tree (AST).

Exceptions / Errors

LexerError
A LexerError exception thrown when the Lexer encounters invalid syntax or characters in the source code.
ParseError
An exception thrown when the Parser encounters a syntax error that violates the grammar rules of the language subset.